Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(994)

Unified Diff: test/mjsunit/regress/regress-prepare-break-while-recompile.js

Issue 23014007: Rename "parallel recompilation" to "concurrent recompilation". (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « test/mjsunit/regress/regress-opt-after-debug-deopt.js ('k') | test/mjsunit/tools/profviz-test.log » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: test/mjsunit/regress/regress-prepare-break-while-recompile.js
diff --git a/test/mjsunit/regress/regress-prepare-break-while-recompile.js b/test/mjsunit/regress/regress-prepare-break-while-recompile.js
index e4941738562747e6f6e04a0091a46a7435067f52..2fad5ca0d295c71601393609d8f6fd9622ec7f7d 100644
--- a/test/mjsunit/regress/regress-prepare-break-while-recompile.js
+++ b/test/mjsunit/regress/regress-prepare-break-while-recompile.js
@@ -26,10 +26,10 @@
// OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
// Flags: --expose-debug-as debug --allow-natives-syntax
-// Flags: --parallel-recompilation-delay=300
+// Flags: --concurrent-recompilation-delay=300
-if (!%IsParallelRecompilationSupported()) {
- print("Parallel recompilation is disabled. Skipping this test.");
+if (!%IsConcurrentRecompilationSupported()) {
+ print("Concurrent recompilation is disabled. Skipping this test.");
quit();
}
@@ -46,8 +46,8 @@ function bar() {
}
foo();
// Mark and trigger parallel optimization.
%OptimizeFunctionOnNextCall(foo, "parallel");
foo();
// Set break points on an unrelated function. This clears both optimized
@@ -56,7 +56,7 @@ foo();
Debug.setBreakPoint(bar, 0, 0);
Debug.clearAllBreakPoints();
// Install optimized code when parallel optimization finishes.
// This needs to be able to deal with shared code being a builtin.
assertUnoptimized(foo, "sync");
« no previous file with comments | « test/mjsunit/regress/regress-opt-after-debug-deopt.js ('k') | test/mjsunit/tools/profviz-test.log » ('j') | no next file with comments »
@@ -46,8 +46,8 @@ function bar() {
}
foo();
-// Mark and trigger parallel optimization.
-%OptimizeFunctionOnNextCall(foo, "parallel");
+// Mark and trigger concurrent optimization.
+%OptimizeFunctionOnNextCall(foo, "concurrent");
foo();
// Set break points on an unrelated function. This clears both optimized
@@ -56,7 +56,7 @@ foo();
Debug.setBreakPoint(bar, 0, 0);
Debug.clearAllBreakPoints();
-// Install optimized code when parallel optimization finishes.
+// Install optimized code when concurrent optimization finishes.
// This needs to be able to deal with shared code being a builtin.
assertUnoptimized(foo, "sync");

Powered by Google App Engine
This is Rietveld 408576698